@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import fnmatch
 import logging
 import os
 import os.path
 import re
 from pathlib import PurePath, PurePosixPath
-from typing import Iterator, Optional, Tuple
+from typing import Iterator
 
 import mkdocs.config
 import mkdocs.config.config_options
@@ -22,12 +24,13 @@ except ImportError:
 from mkdocs_literate_nav import parser
 
 log = logging.getLogger(f"mkdocs.plugins.{__name__}")
-log.addFilter(mkdocs.utils.warning_filter)
 
 
 class _PluginConfig:
     nav_file = mkdocs.config.config_options.Type(str, default="SUMMARY.md")
     implicit_index = mkdocs.config.config_options.Type(bool, default=False)
+    markdown_extensions = mkdocs.config.config_options.MarkdownExtensions()
+    tab_length = mkdocs.config.config_options.Type(int, default=4)
 
 
 class LiterateNavPlugin(mkdocs.plugins.BasePlugin):
@@ -44,6 +47,11 @@ class LiterateNavPlugin(mkdocs.plugins.BasePlugin):
             files,
             nav_file_name=self.config["nav_file"],
             implicit_index=self.config["implicit_index"],
+            markdown_config=dict(
+                extensions=self.config["markdown_extensions"],
+                extension_configs=self.config["mdx_configs"],
+                tab_length=self.config["tab_length"],
+            ),
         )
         self._files = files
 
@@ -61,7 +69,11 @@ class LiterateNavPlugin(mkdocs.plugins.BasePlugin):
 
 
 def resolve_directories_in_nav(
-    nav_data, files: mkdocs.structure.files.Files, nav_file_name: str, implicit_index: bool
+    nav_data,
+    files: mkdocs.structure.files.Files,
+    nav_file_name: str,
+    implicit_index: bool,
+    markdown_config: dict | None = None,
 ):
     """Walk through a standard MkDocs nav config and replace `directory/` references.
 
@@ -69,7 +81,7 @@ def resolve_directories_in_nav(
     If it has a literate nav file, that is used. Otherwise an implicit nav is generated.
     """
 
-    def get_nav_for_dir(path: str) -> Optional[Tuple[str, str]]:
+    def get_nav_for_dir(path: str) -> tuple[str, str] | None:
         file = files.get_file_from_path(os.path.join(path, nav_file_name))
         if not file:
             return None
@@ -85,7 +97,9 @@ def resolve_directories_in_nav(
             return nav_file_name, f.read()
 
     globber = MkDocsGlobber(files)
-    nav_parser = parser.NavParser(get_nav_for_dir, globber, implicit_index=implicit_index)
+    nav_parser = parser.NavParser(
+        get_nav_for_dir, globber, implicit_index=implicit_index, markdown_config=markdown_config
+    )
 
     result = None
     if not nav_data or get_nav_for_dir("."):
@@ -129,7 +143,7 @@ class MkDocsGlobber:
                     if all(re_part.match(part) for part, re_part in zipped):
                         yield str(path)[1:]
 
-    def find_index(self, root: str) -> Optional[str]:
+    def find_index(self, root: str) -> str | None:
         root_path = PurePosixPath("/", root)
         if root_path in self.index_dirs:
             return str(self.index_dirs[root_path])[1:]
